# NestedText: A Human-Friendly Data Format

Python implementation of the NestedText spec, version 2.0.

**Note that this is a simplified fork of the original project <https://github.com/KenKundert/nestedtext> with authors Ken & Kale Kundert. Please see that project for the official language spec.**


## Related Projects

[NestedText spec/docs](https://nestedtext.org)

[Implementation of NestedText in Zig](https://github.com/LewisGaul/zig-nestedtext)

[Official NestedText test suite](https://github.com/kenkundert/nestedtext_tests)

[Vim syntax files for NestedText](https://github.com/kalekundert/vim-nestedtext)

[Syntax files for Visual Studio](https://marketplace.visualstudio.com/items?itemName=bmarkovic17.nestedtext)


## Development

Run the tests with `pytest` (after `pip install -r requirements.txt`).
